#!/bin/bash

if [ $# -lt 1 ]; then
	echo "Usage: ./script/buildrpm.sh config_file"
	exit;
fi

if ! [ -f $1 ]; then
	echo "config_file(%$1) not a regular file!"
	exit;
fi

CFILE=$1
ARCH=`uname -m`
TOPDIR=`pwd`/rpmbuild
DCONF=""

git clean -df
rm -rf rpmbuild/BUILD
rm -rf rpmbuild/BUILDROOT

rm -rf rpmbuild/kernel
mkdir rpmbuild/kernel
make mrproper -j 16

rsync -av --exclude rpmbuild --exclude .git . rpmbuild/kernel/

#prepare the config file
if [ "$ARCH" == "aarch64" ]; then
	cp $CFILE rpmbuild/kernel/arch/arm64/configs/kylinos_defconfig
	DCONF="rpmbuild/kernel/arch/arm64/configs/kylinos_defconfig"
elif [ "$ARCH" == "x86_64" ]; then
	cp $CFILE rpmbuild/kernel/arch/x86/configs/kylinos_defconfig
	DCONF="rpmbuild/kernel/arch/x86/configs/kylinos_defconfig"
else
	echo "unrecognized arch, aborting the building!"
	exit
fi

#prepare the kernel version
CLOCV=`cat $DCONF | grep ^CONFIG_LOCALVERSION=`
if [ $? -eq 0 ]; then
	LOCV=`echo $CLOCV | awk -F\" '{print $2}'`
	sed -i '/^CONFIG_LOCALVERSION=.*/d' $DCONF
	KREL=`cat Makefile  | grep ^EXTRAVERSION | awk -F- '{print $2}'`$LOCV
else
	KREL=`cat Makefile  | grep ^EXTRAVERSION | awk -F- '{print $2}'`
fi

KVER=`make kernelversion  | awk -F- '{print $1}'`
sed -i "s/^Version:.*/Version: $KVER/" rpmbuild/SPECS/kernel.spec

#prepare kernel.tar.gz
cd rpmbuild
tar cvf kernel.tar kernel
gzip kernel.tar
cd ../
rm -rf rpmbuild/SOURCES/kernel.tar.gz
mv rpmbuild/kernel.tar.gz rpmbuild/SOURCES/kernel.tar.gz

#do building
rpmbuild  -bb rpmbuild/SPECS/kernel.spec --define="_topdir $TOPDIR"

#clean work
if [ $? -eq 0 ]; then
	echo "building rpm success..."
	rm -rf rpmbuild/kernel
else
	echo "building failed..."
	exit
fi

#archive RPMS
RPMDIR=${TOPDIR}/RPMS/${ARCH}
KVRELEASE=${KVER}-${KREL}.ky10.${ARCH}
rm -rf rpmbuild/${KVRELEASE}*
mkdir rpmbuild/$KVRELEASE
TARLIST="kernel kernel-devel kernel-tools kernel-tools-devel perf python2-perf python3-perf bpftool"
for rpmpkg in $TARLIST; do
	cp $RPMDIR/${rpmpkg}-${KVRELEASE}.rpm rpmbuild/$KVRELEASE
	if [ $? -ne 0 ]; then
		exit
	fi
done
cd rpmbuild
tar cvf ${KVRELEASE}.tar $KVRELEASE
gzip ${KVRELEASE}.tar
rm -rf $KVRELEASE ${KVRELEASE}.tar
echo -e "archive all builded rpm packages except the debug packages in: \nrpmbuild/${KVRELEASE}.tar.gz"
cd ..
